/* This script shows how to use the RxUnzip add-on DLL to extract the
 * contents of a ZIP archive. NOTE: To create the test archive, run the
 * ZipVars.rex example.
 */

OPTIONS "C_CALL"

/* Register the RxUnzip add-on DLL */
LIBRARY rxunzip

/* Tell RxUnzip to raise SYNTAX condition for any failure with an Unzip function */
ZipErr = "SYNTAX"
ZipHeading = 1

DO
	/* Open a ZIP archive named "MyTest.zip" on disk (in the current directory).
	 * Store the ZIP handle in a variable named "ZipHandle".
	 */
	UnzipOpen("ZipHandle", "MyTest.zip")

	/* Determine how many items are in the archive. */
	UnzipFindItem(ZipHandle, "Count")

	/* Unzip each item in the archive. */
	DO i = 1 TO Count

		/* Set the next item as the current item, and get info on it. */
		UnzipSetCurrentItem(ZipHandle, "Info", i)

		SAY "Unzipping..." Info.0
		SAY "Size =" Info.1
		SAY "Access Time =" Info.4
		SAY "Creation Time =" Info.5
		SAY "Last Modified Time =" Info.6

		UnzipGetItem(ZipHandle, Info.0)
	END

	/* We're done with our ZIP archive on disk, so just let the FINALLY section close it. */

	CATCH SYNTAX
		CONDITION('M')

	FINALLY
		/* Make sure any ZIP archive we opened above is closed. */
		IF EXISTS("ZIPHANDLE") THEN UnzipClose(ZipHandle)
END
