/* Sets all track name events to "Track XX" where XX is the track number.
 */

OPTIONS "C_CALL LABELCHECK NOSOURCE"

/* Add the REXX GUI and RxMidi functions. */
LIBRARY rexxgui, rxmidi

/* Trap errors in RxMidi functions. So, we don't have to check the return values
 * from MIDI REXX functions that set the ERROR condition, such as MIDISetEvent().
 */
MidiErr = "ERROR"
MidiHeading = 1

/* Print an introduction */
IF GuiSay('This script sets all track name events to "Track XX" where XX is the track number. Proceed?', 'YES|INFO') \= 'YES' THEN SIGNAL out

/* Check if we have a MIDI file name. We get the filename from
 * the command line (ie, the user typed it after disasm.rex), or
 * if not supplied, we bring up the file dialog.
 */
IF ARG() < 1 THEN DO
	error = GuiFile('FromFilename', 'EXISTING', 'Enter a name for the new MIDI file', 'MIDI files (*.mid, *.rmi) | *.mid;*.rmi | All files (*.*) | *.*')
	IF error \= "" THEN SIGNAL out
END
ELSE FromFilename = ARG(1)

/* Check if we have a MIDI file name. We get the filename from
 * the command line (ie, the user typed it after disasm.rex), or
 * if not supplied, we bring up the file dialog.
 */
IF ARG() < 1 THEN DO
	error = GuiFile('FromFilename', 'EXISTING', 'Enter a name for the new MIDI file', 'MIDI files (*.mid, *.rmi) | *.mid;*.rmi | All files (*.*) | *.*')
	IF error \== "" THEN RETURN
END
ELSE FromFilename = ARG(1)

DO
	/* Open a MIDI file */
	MIDIOpenFile(FromFilename)

	/* Move to the start of the next track */
	DO WHILE MIDITrack("") \= 0

		/* For each Track Name event in this track... */
		DO WHILE MIDIGetEvent('Trac') = ""

			MIDIEvent.!Data1 = "Track" MIDITrack()
			MIDISetEvent('DATA')

		END /* DO WHILE MIDIGetEvent */

	END /* DO WHILE MIDITrack */

	/* Save to a MIDI file with an underscore prepended to the name */
	/*
	name = FILESPEC('N', FromFilename)
	path = LEFT(FromFilename, LENGTH(FromFilename) - LENGTH(name))
	MIDISaveFile(path || '_' || name)
*/

	CATCH ERROR
		CONDITION('M')
END

RETURN